==> webkit2gtk_2.50.1.orig.tar.xz: webkitgtk-2.50.1/Source/WebCore/Modules/mediasession/NavigatorMediaSession.h <==
/*
 * Copyright (C) 2020-2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(MEDIA_SESSION)

#include "Supplementable.h"
#include <wtf/CheckedRef.h>
#include <wtf/Forward.h>
#include <wtf/TZoneMalloc.h>

namespace WebCore {

class MediaSession;
class Navigator;

class NavigatorMediaSession final : public Supplement<Navigator> {
    WTF_MAKE_TZONE_ALLOCATED(NavigatorMediaSession);
public:
    explicit NavigatorMediaSession(Navigator&);
    ~NavigatorMediaSession();

    WEBCORE_EXPORT static MediaSession& mediaSession(Navigator&);
    WEBCORE_EXPORT static RefPtr<MediaSession> mediaSessionIfExists(Navigator&);
    MediaSession& mediaSession();
    RefPtr<MediaSession> mediaSessionIfExists();

private:
    static NavigatorMediaSession* from(Navigator&);
    static ASCIILiteral supplementName();

    const RefPtr<MediaSession> m_mediaSession;
    const CheckedRef<Navigator> m_navigator;
};

}

#endif // ENABLE(MEDIA_SESSION)

==> webkit2gtk_2.51.90.orig.tar.xz: webkitgtk-2.51.90/Source/WebCore/Modules/mediasession/NavigatorMediaSession.h <==
/*
 * Copyright (C) 2020-2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(MEDIA_SESSION)

#include <WebCore/Supplementable.h>
#include <wtf/CheckedRef.h>
#include <wtf/Forward.h>
#include <wtf/TZoneMalloc.h>

namespace WebCore {

class MediaSession;
class Navigator;

class NavigatorMediaSession final : public Supplement<Navigator> {
    WTF_MAKE_TZONE_ALLOCATED(NavigatorMediaSession);
public:
    explicit NavigatorMediaSession(Navigator&);
    ~NavigatorMediaSession();

    WEBCORE_EXPORT static MediaSession& mediaSession(Navigator&);
    WEBCORE_EXPORT static RefPtr<MediaSession> mediaSessionIfExists(Navigator&);
    MediaSession& mediaSession();
    RefPtr<MediaSession> mediaSessionIfExists();

private:
    static NavigatorMediaSession* from(Navigator&);
    static ASCIILiteral supplementName() { return "NavigatorMediaSession"_s; }
    bool isNavigatorMediaSession() const final { return true; }

    const RefPtr<MediaSession> m_mediaSession;
    const CheckedRef<Navigator> m_navigator;
};

} // namespace WebCore

SPECIALIZE_TYPE_TRAITS_BEGIN(WebCore::NavigatorMediaSession)
    static bool isType(const WebCore::SupplementBase& supplement) { return supplement.isNavigatorMediaSession(); }
SPECIALIZE_TYPE_TRAITS_END()

#endif // ENABLE(MEDIA_SESSION)
